@@ -6,7 +6,7 @@ use Params::Validate qw(:types);
 
 use SVG::Rasterize::Regexes qw(:attributes);
 
-# $Id: Font.pm 6211 2010-06-15 04:21:13Z mullet $
+# $Id: Font.pm 6484 2011-04-21 09:25:12Z powergnom $
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ C<SVG::Rasterize::Specification::Font> - specification for class Font
 
 =head1 VERSION
 
-Version 0.003004
+Version 0.003005
 
 =cut
 
-our $VERSION = '0.003004';
+our $VERSION = '0.003005';
 
 our %CHILDREN = ('font'      => {'desc'           => 1,
                                  'font-face'      => 1,
@@ -39,16 +39,16 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/^(?:auto|baseline|before\-edge|text\-before\-edge|middle|central|after\-edge|text\-after\-edge|ideographic|alphabetic|hanging|mathematical|inherit)$/},
                                  'baseline-shift'               => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'class'                        => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'clip'                         => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'clip-path'                    => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'clip-rule'                    => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
@@ -63,13 +63,13 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/^(?:auto|sRGB|linearRGB|inherit)$/},
                                  'color-profile'                => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'color-rendering'              => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:auto|optimizeSpeed|optimizeQuality|inherit)$/},
                                  'cursor'                       => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'direction'                    => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:ltr|rtl|inherit)$/},
@@ -81,7 +81,7 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/^(?:auto|use\-script|no\-change|reset\-size|ideographic|alphabetic|hanging|mathematical|central|middle|text\-after\-edge|text\-before\-edge|inherit)$/},
                                  'enable-background'            => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'externalResourcesRequired'    => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:false|true)$/},
@@ -96,22 +96,22 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
                                  'filter'                       => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'flood-color'                  => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'flood-opacity'                => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
                                  'font-family'                  => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'font-size'                    => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'font-size-adjust'             => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'font-stretch'                 => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:normal|wider|narrower|ultra\-condensed|extra\-condensed|condensed|semi\-condensed|semi\-expanded|expanded|extra\-expanded|ultra\-expanded|inherit)$/},
@@ -126,10 +126,10 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/^(?:normal|bold|bolder|lighter|100|200|300|400|500|600|700|800|900|inherit)$/},
                                  'glyph-orientation-horizontal' => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'glyph-orientation-vertical'   => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'horiz-adv-x'                  => {'optional' => 0,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
@@ -141,31 +141,31 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
                                  'id'                           => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => $RE_XML{p_NAME}},
                                  'image-rendering'              => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:auto|optimizeSpeed|optimizeQuality|inherit)$/},
                                  'kerning'                      => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'letter-spacing'               => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'lighting-color'               => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'marker-end'                   => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'marker-mid'                   => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'marker-start'                 => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'mask'                         => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'opacity'                      => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
@@ -180,7 +180,7 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/^(?:auto|optimizeSpeed|crispEdges|geometricPrecision|inherit)$/},
                                  'stop-color'                   => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'stop-opacity'                 => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
@@ -210,13 +210,13 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/$RE_LENGTH{p_A_LENGTH}|^inherit$/},
                                  'style'                        => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'text-anchor'                  => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:start|middle|end|inherit)$/},
                                  'text-decoration'              => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'text-rendering'               => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:auto|optimizeSpeed|optimizeLegibility|geometricPrecision|inherit)$/},
@@ -237,16 +237,16 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => qr/^(?:visible|hidden|inherit)$/},
                                  'word-spacing'                 => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'writing-mode'                 => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:lr\-tb|rl\-tb|tb\-rl|lr|rl|tb|inherit)$/},
                                  'xml:base'                     => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'xml:lang'                     => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => $RE_XML{p_NMTOKEN}},
                                  'xml:space'                    => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:default|preserve)$/}},
@@ -261,7 +261,7 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
                                  'bbox'                         => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'cap-height'                   => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
@@ -270,28 +270,28 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
                                  'font-family'                  => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'font-size'                    => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'font-stretch'                 => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'font-style'                   => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'font-variant'                 => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'font-weight'                  => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'hanging'                      => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
                                  'id'                           => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => $RE_XML{p_NAME}},
                                  'ideographic'                  => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
@@ -306,7 +306,7 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
                                  'panose-1'                     => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'slope'                        => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
@@ -330,7 +330,7 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
                                  'unicode-range'                => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'units-per-em'                 => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
@@ -348,16 +348,16 @@ our %ATTR_VAL = ('font'      => {'alignment-baseline'           => {'optional' =
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
                                  'widths'                       => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'x-height'                     => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => $RE_NUMBER{p_A_NUMBER}},
                                  'xml:base'                     => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => qr/.?/},
                                  'xml:lang'                     => {'optional' => 1,
                                                                     'type'     => SCALAR,
-                                                                    'regex'    => qr//},
+                                                                    'regex'    => $RE_XML{p_NMTOKEN}},
                                  'xml:space'                    => {'optional' => 1,
                                                                     'type'     => SCALAR,
                                                                     'regex'    => qr/^(?:default|preserve)$/}});
@@ -392,7 +392,7 @@ Lutz Gehlen, C<< <perl at lutzgehlen.de> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Lutz Gehlen.
+Copyright 2010-2011 Lutz Gehlen.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of either: the GNU General Public License as
