@@ -6,7 +6,7 @@ use Params::Validate qw(:types);
 
 use SVG::Rasterize::Regexes qw(:attributes);
 
-# $Id: Image.pm 6211 2010-06-15 04:21:13Z mullet $
+# $Id: Image.pm 6484 2011-04-21 09:25:12Z powergnom $
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ C<SVG::Rasterize::Specification::Image> - specification for class Image
 
 =head1 VERSION
 
-Version 0.003004
+Version 0.003005
 
 =cut
 
-our $VERSION = '0.003004';
+our $VERSION = '0.003005';
 
 our %CHILDREN = ('image' => {'animate'          => 1,
                              'animateColor'     => 1,
@@ -31,13 +31,13 @@ our %CHILDREN = ('image' => {'animate'          => 1,
 
 our %ATTR_VAL = ('image' => {'class'                     => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'clip'                      => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'clip-path'                 => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'clip-rule'                 => {'optional' => 1,
                                                              'type'     => SCALAR,
                                                              'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
@@ -49,13 +49,13 @@ our %ATTR_VAL = ('image' => {'class'                     => {'optional' => 1,
                                                              'regex'    => qr/^(?:auto|sRGB|linearRGB|inherit)$/},
                              'color-profile'             => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'color-rendering'           => {'optional' => 1,
                                                              'type'     => SCALAR,
                                                              'regex'    => qr/^(?:auto|optimizeSpeed|optimizeQuality|inherit)$/},
                              'cursor'                    => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'display'                   => {'optional' => 1,
                                                              'type'     => SCALAR,
                                                              'regex'    => qr/^(?:inline|block|list\-item|run\-in|compact|marker|table|inline\-table|table\-row\-group|table\-header\-group|table\-footer\-group|table\-row|table\-column\-group|table\-column|table\-cell|table\-caption|none|inherit)$/},
@@ -67,49 +67,49 @@ our %ATTR_VAL = ('image' => {'class'                     => {'optional' => 1,
                                                              'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
                              'filter'                    => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'height'                    => {'optional' => 0,
                                                              'type'     => SCALAR,
                                                              'regex'    => $RE_LENGTH{p_A_LENGTH}},
                              'id'                        => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => $RE_XML{p_NAME}},
                              'image-rendering'           => {'optional' => 1,
                                                              'type'     => SCALAR,
                                                              'regex'    => qr/^(?:auto|optimizeSpeed|optimizeQuality|inherit)$/},
                              'mask'                      => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'onactivate'                => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'onclick'                   => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'onfocusin'                 => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'onfocusout'                => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'onload'                    => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'onmousedown'               => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'onmousemove'               => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'onmouseout'                => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'onmouseover'               => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'onmouseup'                 => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'opacity'                   => {'optional' => 1,
                                                              'type'     => SCALAR,
                                                              'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
@@ -121,13 +121,13 @@ our %ATTR_VAL = ('image' => {'class'                     => {'optional' => 1,
                                                              'regex'    => qr/^(?:visiblePainted|visibleFill|visibleStroke|visible|painted|fill|stroke|all|none|inherit)$/},
                              'preserveAspectRatio'       => {'default'  => 'xMidYMid meet',
                                                              'type'     => SCALAR,
-                                                             'regex'    => $RE_VIEW_BOX{PAR}},
+                                                             'regex'    => $RE_VIEW_BOX{p_PAR}},
                              'requiredExtensions'        => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'requiredFeatures'          => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'shape-rendering'           => {'optional' => 1,
                                                              'type'     => SCALAR,
                                                              'regex'    => qr/^(?:auto|optimizeSpeed|crispEdges|geometricPrecision|inherit)$/},
@@ -136,10 +136,10 @@ our %ATTR_VAL = ('image' => {'class'                     => {'optional' => 1,
                                                              'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
                              'style'                     => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'systemLanguage'            => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'text-rendering'            => {'optional' => 1,
                                                              'type'     => SCALAR,
                                                              'regex'    => qr/^(?:auto|optimizeSpeed|optimizeLegibility|geometricPrecision|inherit)$/},
@@ -160,34 +160,34 @@ our %ATTR_VAL = ('image' => {'class'                     => {'optional' => 1,
                                                              'regex'    => qr/^(?:onLoad)$/},
                              'xlink:arcrole'             => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'xlink:href'                => {'optional' => 0,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'xlink:role'                => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'xlink:show'                => {'default'  => 'embed',
                                                              'type'     => SCALAR,
                                                              'regex'    => qr/^(?:embed)$/},
                              'xlink:title'               => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'xlink:type'                => {'default'  => 'simple',
                                                              'type'     => SCALAR,
                                                              'regex'    => qr/^(?:simple)$/},
                              'xml:base'                  => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'xml:lang'                  => {'optional' => 1,
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => $RE_XML{p_NMTOKEN}},
                              'xml:space'                 => {'optional' => 1,
                                                              'type'     => SCALAR,
                                                              'regex'    => qr/^(?:default|preserve)$/},
                              'xmlns:xlink'               => {'default'  => 'http://www.w3.org/1999/xlink',
                                                              'type'     => SCALAR,
-                                                             'regex'    => qr//},
+                                                             'regex'    => qr/.?/},
                              'y'                         => {'optional' => 1,
                                                              'type'     => SCALAR,
                                                              'regex'    => $RE_LENGTH{p_A_LENGTH}}});
@@ -222,7 +222,7 @@ Lutz Gehlen, C<< <perl at lutzgehlen.de> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Lutz Gehlen.
+Copyright 2010-2011 Lutz Gehlen.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of either: the GNU General Public License as
