@@ -6,7 +6,7 @@ use Params::Validate qw(:types);
 
 use SVG::Rasterize::Regexes qw(:attributes);
 
-# $Id: Text.pm 6211 2010-06-15 04:21:13Z mullet $
+# $Id: Text.pm 6484 2011-04-21 09:25:12Z powergnom $
 
 =head1 NAME
 
@@ -14,11 +14,11 @@ C<SVG::Rasterize::Specification::Text> - specification for class Text
 
 =head1 VERSION
 
-Version 0.003004
+Version 0.003005
 
 =cut
 
-our $VERSION = '0.003004';
+our $VERSION = '0.003005';
 
 our %CHILDREN = ('altGlyphDef' => {'altGlyphItem'     => 1,
                                    'glyphRef'         => 1},
@@ -38,13 +38,13 @@ our %CHILDREN = ('altGlyphDef' => {'altGlyphItem'     => 1,
 
 our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => $RE_XML{p_NAME}},
                                    'xml:base'                     => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'xml:lang'                     => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => $RE_XML{p_NMTOKEN}},
                                    'xml:space'                    => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:default|preserve)$/}},
@@ -53,13 +53,13 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => qr/^(?:auto|baseline|before\-edge|text\-before\-edge|middle|central|after\-edge|text\-after\-edge|ideographic|alphabetic|hanging|mathematical|inherit)$/},
                                    'baseline-shift'               => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'class'                        => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'clip-path'                    => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'clip-rule'                    => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
@@ -74,7 +74,7 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => qr/^(?:auto|optimizeSpeed|optimizeQuality|inherit)$/},
                                    'cursor'                       => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'direction'                    => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:ltr|rtl|inherit)$/},
@@ -104,16 +104,16 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => qr/^(?:nonzero|evenodd|inherit)$/},
                                    'filter'                       => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'font-family'                  => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'font-size'                    => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'font-size-adjust'             => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'font-stretch'                 => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:normal|wider|narrower|ultra\-condensed|extra\-condensed|condensed|semi\-condensed|semi\-expanded|expanded|extra\-expanded|ultra\-expanded|inherit)$/},
@@ -128,58 +128,58 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => qr/^(?:normal|bold|bolder|lighter|100|200|300|400|500|600|700|800|900|inherit)$/},
                                    'glyph-orientation-horizontal' => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'glyph-orientation-vertical'   => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'id'                           => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => $RE_XML{p_NAME}},
                                    'image-rendering'              => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:auto|optimizeSpeed|optimizeQuality|inherit)$/},
                                    'kerning'                      => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'lengthAdjust'                 => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:spacing|spacingAndGlyphs)$/},
                                    'letter-spacing'               => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'mask'                         => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'onactivate'                   => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'onclick'                      => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'onfocusin'                    => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'onfocusout'                   => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'onload'                       => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'onmousedown'                  => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'onmousemove'                  => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'onmouseout'                   => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'onmouseover'                  => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'onmouseup'                    => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'opacity'                      => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/$RE_NUMBER{p_A_NUMBER}|^inherit$/},
@@ -188,13 +188,13 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => qr/^(?:visiblePainted|visibleFill|visibleStroke|visible|painted|fill|stroke|all|none|inherit)$/},
                                    'requiredExtensions'           => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'requiredFeatures'             => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'rotate'                       => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'shape-rendering'              => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:auto|optimizeSpeed|crispEdges|geometricPrecision|inherit)$/},
@@ -224,16 +224,16 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => qr/$RE_LENGTH{p_A_LENGTH}|^inherit$/},
                                    'style'                        => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'systemLanguage'               => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'text-anchor'                  => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:start|middle|end|inherit)$/},
                                    'text-decoration'              => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'text-rendering'               => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:auto|optimizeSpeed|optimizeLegibility|geometricPrecision|inherit)$/},
@@ -251,7 +251,7 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => qr/^(?:visible|hidden|inherit)$/},
                                    'word-spacing'                 => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'writing-mode'                 => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:lr\-tb|rl\-tb|tb\-rl|lr|rl|tb|inherit)$/},
@@ -260,10 +260,10 @@ our %ATTR_VAL = ('altGlyphDef' => {'id'                           => {'optional'
                                                                       'regex'    => $RE_LENGTH{p_A_LENGTHS}},
                                    'xml:base'                     => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => qr/.?/},
                                    'xml:lang'                     => {'optional' => 1,
                                                                       'type'     => SCALAR,
-                                                                      'regex'    => qr//},
+                                                                      'regex'    => $RE_XML{p_NMTOKEN}},
                                    'xml:space'                    => {'optional' => 1,
                                                                       'type'     => SCALAR,
                                                                       'regex'    => qr/^(?:default|preserve)$/},
@@ -302,7 +302,7 @@ Lutz Gehlen, C<< <perl at lutzgehlen.de> >>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 Lutz Gehlen.
+Copyright 2010-2011 Lutz Gehlen.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of either: the GNU General Public License as
